Index: 3rdparty/mmu_man/themes/addons/DeskbarAddon.cpp
===================================================================
--- 3rdparty/mmu_man/themes/addons/DeskbarAddon.cpp	(revision 25223)
+++ 3rdparty/mmu_man/themes/addons/DeskbarAddon.cpp	(working copy)
@@ -59,7 +59,7 @@
 	status_t err;
 	entry_ref ref;
 	BEntry ent;
-	err = ent.SetTo("/boot/beos/preferences/Deskbar");
+	err = ent.SetTo("/boot/haiku/preferences/Deskbar");
 	if (!err) {
 		err = ent.GetRef(&ref);
 		if (!err) {
Index: 3rdparty/mmu_man/themes/addons/SoundsAddon.cpp
===================================================================
--- 3rdparty/mmu_man/themes/addons/SoundsAddon.cpp	(revision 25223)
+++ 3rdparty/mmu_man/themes/addons/SoundsAddon.cpp	(working copy)
@@ -63,7 +63,7 @@
 	status_t err;
 	entry_ref ref;
 	BEntry ent;
-	err = ent.SetTo("/boot/beos/preferences/Sounds");
+	err = ent.SetTo("/boot/haiku/preferences/Sounds");
 	if (!err) {
 		err = ent.GetRef(&ref);
 		if (!err) {
Index: 3rdparty/mmu_man/themes/addons/HaikuUISettingsAddon.cpp
===================================================================
--- 3rdparty/mmu_man/themes/addons/HaikuUISettingsAddon.cpp	(revision 25223)
+++ 3rdparty/mmu_man/themes/addons/HaikuUISettingsAddon.cpp	(working copy)
@@ -126,7 +126,7 @@
 	*/
 	if (!err)
 		return B_OK;
-	err = ent.SetTo("/boot/beos/preferences/Appearance");
+	err = ent.SetTo("/boot/haiku/preferences/Appearance");
 	if (!err) {
 		err = ent.GetRef(&ref);
 		if (!err) {
Index: 3rdparty/mmu_man/themes/addons/ScreensaverAddon.cpp
===================================================================
--- 3rdparty/mmu_man/themes/addons/ScreensaverAddon.cpp	(revision 25223)
+++ 3rdparty/mmu_man/themes/addons/ScreensaverAddon.cpp	(working copy)
@@ -68,7 +68,7 @@
 	status_t err;
 	entry_ref ref;
 	BEntry ent;
-	err = ent.SetTo("/boot/beos/preferences/ScreenSaver");
+	err = ent.SetTo("/boot/haiku/preferences/ScreenSaver");
 	if (!err) {
 		err = ent.GetRef(&ref);
 		if (!err) {
Index: 3rdparty/mmu_man/themes/addons/BackgroundsAddon.cpp
===================================================================
--- 3rdparty/mmu_man/themes/addons/BackgroundsAddon.cpp	(revision 25223)
+++ 3rdparty/mmu_man/themes/addons/BackgroundsAddon.cpp	(working copy)
@@ -80,7 +80,7 @@
 	status_t err;
 	entry_ref ref;
 	BEntry ent;
-	err = ent.SetTo("/boot/beos/preferences/Backgrounds");
+	err = ent.SetTo("/boot/haiku/preferences/Backgrounds");
 	if (!err) {
 		err = ent.GetRef(&ref);
 		if (!err) {
Index: 3rdparty/mmu_man/themes/addons/HaikuWindowDecorAddon.cpp
===================================================================
--- 3rdparty/mmu_man/themes/addons/HaikuWindowDecorAddon.cpp	(revision 25223)
+++ 3rdparty/mmu_man/themes/addons/HaikuWindowDecorAddon.cpp	(working copy)
@@ -99,7 +99,7 @@
 	status_t err;
 	entry_ref ref;
 	BEntry ent;
-	err = ent.SetTo("/boot/beos/references/Appearance");
+	err = ent.SetTo("/boot/haiku/references/Appearance");
 	if (!err) {
 		err = ent.GetRef(&ref);
 		if (!err) {
Index: 3rdparty/mmu_man/themes/ThemeManager.cpp
===================================================================
--- 3rdparty/mmu_man/themes/ThemeManager.cpp	(revision 25223)
+++ 3rdparty/mmu_man/themes/ThemeManager.cpp	(working copy)
@@ -879,7 +879,7 @@
 
 	err = ThemeLocation(id, location);
 	if (!err) {
-		if (location.FindFirst("/boot/beos") >= 0) {
+		if (location.FindFirst("/boot/haiku") >= 0) {
 			PRINT(("trying to save theme '%s' to system dir!\n", name.String()));
 			return B_PERMISSION_DENIED;
 		}
@@ -1087,7 +1087,7 @@
 	err = ThemeLocation(id, s);
 	if (err)
 		return true;
-	if (s.FindFirst("/boot/beos") >= 0)
+	if (s.FindFirst("/boot/haiku") >= 0)
 		return true;
 	return false;
 }
Index: build/jam/UserBuildConfig.ReadMe
===================================================================
--- build/jam/UserBuildConfig.ReadMe	(revision 25223)
+++ build/jam/UserBuildConfig.ReadMe	(working copy)
@@ -14,7 +14,7 @@
 
 # Adding timezone and keymap settings
 AddSymlinkToHaikuImage home config settings
-	: /boot/beos/etc/timezones/Europe/Paris : timezone ;
+	: /boot/haiku/etc/timezones/Europe/Paris : timezone ;
 
 AddFilesToHaikuImage home config settings : <keymap>US-International 
 	: Key_map ;
@@ -88,13 +88,13 @@
 # has been added, like for "kernel").
 HAIKU_INCLUDE_IN_IMAGE on libbe.so kernel = 1 ;
 
-# Add "crashing_app" to the beos/bin directory of the Haiku image/installation.
+# Add "crashing_app" to the haiku/bin directory of the Haiku image/installation.
 # Note, that this also makes the image depend on the target, i.e. it is
 # automatically updated when the image is built.
-AddFilesToHaikuImage beos bin : crashing_app ;
+AddFilesToHaikuImage haiku bin : crashing_app ;
 
 # Make a symlink to home/config/bin/crash.
-AddSymlinkToHaikuImage home config bin : /beos/bin/crashing_app : crash ;
+AddSymlinkToHaikuImage home config bin : /haiku/bin/crashing_app : crash ;
 
 # Adds the source directories src/kits/storage and src/tests/servers/debug
 # (recursively) to the image (as /boot/home/HaikuSources/src/kits/storage
Index: build/jam/OptionalPackages
===================================================================
--- build/jam/OptionalPackages	(revision 25223)
+++ build/jam/OptionalPackages	(working copy)
@@ -38,7 +38,7 @@
 	AddFilesToHaikuImage develop lib x86 : libncurses.a ;
 
 	# cc and c++ wrapper scripts
-	AddFilesToHaikuImage beos bin : cc c++ ;
+	AddFilesToHaikuImage haiku bin : cc c++ ;
 
 	# headers
 	AddHeaderDirectoryToHaikuImage gnu : 3rdparty ;
Index: build/jam/ImageRules
===================================================================
--- build/jam/ImageRules	(revision 25223)
+++ build/jam/ImageRules	(working copy)
@@ -246,10 +246,10 @@
 {
 	# AddDriversToContainer <container> : <relative directory> : <targets> ;
 	#
-	local directoryTokens = beos system add-ons kernel drivers dev
+	local directoryTokens = haiku system add-ons kernel drivers dev
 		$(relativeDirectoryTokens) ;
 
-	AddFilesToContainer $(container) : beos system add-ons kernel drivers bin
+	AddFilesToContainer $(container) : haiku system add-ons kernel drivers bin
 		: $(targets) ;
 
 	# If the image shall only be updated, we don't add any symlinks.
@@ -278,7 +278,7 @@
 	# AddDriverRegistrationToContainer <container> : <directory>
 	#	: <link target> : <link names> ] ;
 	#
-	local directoryTokens = beos system add-ons kernel registration
+	local directoryTokens = haiku system add-ons kernel registration
 		$(relativeDirectoryTokens) ;
 
 	# get the relative symlink path prefix
@@ -321,7 +321,7 @@
 		local name = $(target:BS) ;
 		local linkTarget = [ FDirName /boot $(installDir:G=) $(name) ] ; 
 
-		AddSymlinkToContainer $(container) : beos system add-ons kernel boot
+		AddSymlinkToContainer $(container) : haiku system add-ons kernel boot
 			: $(linkTarget) : $(name) ;
 	}
 }
@@ -688,7 +688,7 @@
 		Always $(file) ;
 		MakeLocate $(file) : $(HAIKU_COMMON_PLATFORM_OBJECT_DIR) ;
 		BuildHaikuImageUserGroupFile $(file) ;
-		AddFilesToHaikuImage beos etc : $(file) ;
+		AddFilesToHaikuImage haiku etc : $(file) ;
 	}
 
 	HAIKU_IMAGE_USER_GROUP_ENTRIES on $(file) = $(allEntries) ;
Index: build/jam/FloppyBootImage
===================================================================
--- build/jam/FloppyBootImage	(revision 25223)
+++ build/jam/FloppyBootImage	(working copy)
@@ -38,24 +38,24 @@
 
 
 # modules
-AddFilesToFloppyBootArchive beos system add-ons kernel bus_managers
+AddFilesToFloppyBootArchive haiku system add-ons kernel bus_managers
 	: $(BEOS_ADD_ONS_BUS_MANAGERS) ;
-AddFilesToFloppyBootArchive beos system add-ons kernel busses agp_gart
+AddFilesToFloppyBootArchive haiku system add-ons kernel busses agp_gart
 	: $(X86_ONLY)<agp_gart>intel ;
-AddFilesToFloppyBootArchive beos system add-ons kernel busses ide
+AddFilesToFloppyBootArchive haiku system add-ons kernel busses ide
 	: ahci generic_ide_pci $(X86_ONLY)ide_isa silicon_image_3112 legacy_sata ;
-AddFilesToFloppyBootArchive beos system add-ons kernel console : vga_text ;
-AddFilesToFloppyBootArchive beos system add-ons kernel file_systems
+AddFilesToFloppyBootArchive haiku system add-ons kernel console : vga_text ;
+AddFilesToFloppyBootArchive haiku system add-ons kernel file_systems
 	: $(BEOS_ADD_ONS_FILE_SYSTEMS) ;
-AddFilesToFloppyBootArchive beos system add-ons kernel generic
+AddFilesToFloppyBootArchive haiku system add-ons kernel generic
 	: block_io fast_log ide_adapter locked_pool scsi_periph ;
-AddFilesToFloppyBootArchive beos system add-ons kernel partitioning_systems
+AddFilesToFloppyBootArchive haiku system add-ons kernel partitioning_systems
 	: intel session ;
-AddFilesToFloppyBootArchive beos system add-ons kernel interrupt_controllers
+AddFilesToFloppyBootArchive haiku system add-ons kernel interrupt_controllers
 	: $(PPC_ONLY)openpic ;
 
 if $(TARGET_ARCH) = x86 {
-	AddFilesToFloppyBootArchive beos system add-ons kernel cpu : generic_x86 ;
+	AddFilesToFloppyBootArchive haiku system add-ons kernel cpu : generic_x86 ;
 }
 
 # drivers
@@ -67,7 +67,7 @@
 }
 
 # kernel
-AddFilesToFloppyBootArchive beos system : <revisioned>kernel_$(TARGET_ARCH) ;
+AddFilesToFloppyBootArchive haiku system : <revisioned>kernel_$(TARGET_ARCH) ;
 
 # scripts and data files
 
@@ -79,15 +79,15 @@
 
 if $(NET_BOOT) = 1 {
 # add-ons
-AddFilesToFloppyBootArchive beos system add-ons kernel network
+AddFilesToFloppyBootArchive haiku system add-ons kernel network
 	: stack socket ;
-AddFilesToFloppyBootArchive beos system add-ons kernel network devices
+AddFilesToFloppyBootArchive haiku system add-ons kernel network devices
 	: $(BEOS_NETWORK_DEVICES) ;
-AddFilesToFloppyBootArchive beos system add-ons kernel network datalink_protocols
+AddFilesToFloppyBootArchive haiku system add-ons kernel network datalink_protocols
 	: $(BEOS_NETWORK_DATALINK_PROTOCOLS) ;
-AddFilesToFloppyBootArchive beos system add-ons kernel network ppp
+AddFilesToFloppyBootArchive haiku system add-ons kernel network ppp
 	: $(BEOS_NETWORK_PPP) ;
-AddFilesToFloppyBootArchive beos system add-ons kernel network protocols
+AddFilesToFloppyBootArchive haiku system add-ons kernel network protocols
 	: $(BEOS_NETWORK_PROTOCOLS) ;
 }
 
Index: build/jam/HaikuImage
===================================================================
--- build/jam/HaikuImage	(revision 25223)
+++ build/jam/HaikuImage	(working copy)
@@ -140,30 +140,30 @@
 
 
 # modules
-AddFilesToHaikuImage beos system add-ons kernel bus_managers
+AddFilesToHaikuImage haiku system add-ons kernel bus_managers
 	: $(BEOS_ADD_ONS_BUS_MANAGERS) ;
-AddFilesToHaikuImage beos system add-ons kernel busses agp_gart
+AddFilesToHaikuImage haiku system add-ons kernel busses agp_gart
 	: $(X86_ONLY)<agp_gart>intel ;
-AddFilesToHaikuImage beos system add-ons kernel busses ide
+AddFilesToHaikuImage haiku system add-ons kernel busses ide
 	: generic_ide_pci $(X86_ONLY)ide_isa silicon_image_3112 legacy_sata ;
-AddFilesToHaikuImage beos system add-ons kernel busses scsi
+AddFilesToHaikuImage haiku system add-ons kernel busses scsi
 	: ahci ;
-AddFilesToHaikuImage beos system add-ons kernel busses usb
+AddFilesToHaikuImage haiku system add-ons kernel busses usb
 	: <usb>uhci <usb>ehci ;
-AddFilesToHaikuImage beos system add-ons kernel console : vga_text ;
-AddFilesToHaikuImage beos system add-ons kernel debugger
+AddFilesToHaikuImage haiku system add-ons kernel console : vga_text ;
+AddFilesToHaikuImage haiku system add-ons kernel debugger
 	: <kdebug>hangman <kdebug>invalidate_on_exit ;
-AddFilesToHaikuImage beos system add-ons kernel file_systems
+AddFilesToHaikuImage haiku system add-ons kernel file_systems
 	: $(BEOS_ADD_ONS_FILE_SYSTEMS) ;
-AddFilesToHaikuImage beos system add-ons kernel generic
+AddFilesToHaikuImage haiku system add-ons kernel generic
 	: block_io dpc fast_log ide_adapter locked_pool mpu401 scsi_periph ;
-AddFilesToHaikuImage beos system add-ons kernel partitioning_systems
+AddFilesToHaikuImage haiku system add-ons kernel partitioning_systems
 	: intel session ;
-AddFilesToHaikuImage beos system add-ons kernel interrupt_controllers
+AddFilesToHaikuImage haiku system add-ons kernel interrupt_controllers
 	: $(PPC_ONLY)openpic ;
 
 if $(TARGET_ARCH) = x86 {
-	AddFilesToHaikuImage beos system add-ons kernel cpu : generic_x86 ;
+	AddFilesToHaikuImage haiku system add-ons kernel cpu : generic_x86 ;
 }
 
 # drivers
@@ -183,10 +183,10 @@
 #AddDriversToHaikuImage power		: $(BEOS_ADD_ONS_DRIVERS_ACPI) ;
 
 # kernel
-AddFilesToHaikuImage beos system : <revisioned>kernel_$(TARGET_ARCH) ;
+AddFilesToHaikuImage haiku system : <revisioned>kernel_$(TARGET_ARCH) ;
 
 # libs
-AddFilesToHaikuImage beos system lib : $(BEOS_SYSTEM_LIBS) ;
+AddFilesToHaikuImage haiku system lib : $(BEOS_SYSTEM_LIBS) ;
 
 # libnetwork.so replaces quite a few libraries
 BEOS_SYSTEM_LIBS_LIBNETWORK_ALIASES
@@ -194,28 +194,28 @@
 
 local lib ;
 for lib in $(BEOS_SYSTEM_LIBS_LIBNETWORK_ALIASES) {
-	AddSymlinkToHaikuImage beos system lib : libnetwork.so : $(lib) ;
+	AddSymlinkToHaikuImage haiku system lib : libnetwork.so : $(lib) ;
 }
 
 # libGL.so has GLUT built-in
 if $(TARGET_ARCH) = x86 {
-	AddSymlinkToHaikuImage beos system lib : $(X86_ONLY)libGL.so : libglut.so ;
+	AddSymlinkToHaikuImage haiku system lib : $(X86_ONLY)libGL.so : libglut.so ;
 }
 
 # servers
-AddFilesToHaikuImage beos system servers : $(BEOS_SYSTEM_SERVERS) ;
+AddFilesToHaikuImage haiku system servers : $(BEOS_SYSTEM_SERVERS) ;
 
 # apps
-AddFilesToHaikuImage beos system		: runtime_loader Deskbar Tracker ;
-AddFilesToHaikuImage beos bin			: $(BEOS_BIN) consoled ;
-AddFilesToHaikuImage beos apps			: $(BEOS_APPS) ;
-AddFilesToHaikuImage beos preferences	: $(BEOS_PREFERENCES) ;
-AddFilesToHaikuImage beos demos			: $(BEOS_DEMOS) ;
+AddFilesToHaikuImage haiku system		: runtime_loader Deskbar Tracker ;
+AddFilesToHaikuImage haiku bin			: $(BEOS_BIN) consoled ;
+AddFilesToHaikuImage haiku apps			: $(BEOS_APPS) ;
+AddFilesToHaikuImage haiku preferences	: $(BEOS_PREFERENCES) ;
+AddFilesToHaikuImage haiku demos			: $(BEOS_DEMOS) ;
 
 SEARCH on which = [ FDirName $(HAIKU_TOP) data bin ] ;
-AddFilesToHaikuImage beos bin			: which ;
+AddFilesToHaikuImage haiku bin			: which ;
 
-AddSymlinkToHaikuImage beos bin : sh : bash ;
+AddSymlinkToHaikuImage haiku bin : sh : bash ;
 
 AddSymlinkToHaikuImage home Desktop : /boot/home : Home ;
 
@@ -228,7 +228,7 @@
 local app ;
 for app in $(DESKBAR_APPLICATIONS) {
 	AddSymlinkToHaikuImage home config be Applications
-		: /boot/beos/apps/$(app) : $(app) ;
+		: /boot/haiku/apps/$(app) : $(app) ;
 }
 
 # Deskbar Desktop Applets links
@@ -238,54 +238,54 @@
 ;
 for app in $(DESKBAR_DESKTOP_APPLETS) {
 	AddSymlinkToHaikuImage home config be Desktop\ Applets
-		: /boot/beos/apps/$(app) : $(app) ;
+		: /boot/haiku/apps/$(app) : $(app) ;
 }
 
 # Deskbar Preferences and Demos links
-AddSymlinkToHaikuImage home config be : /boot/beos/preferences : Preferences ;
-AddSymlinkToHaikuImage home config be : /boot/beos/demos : Demos ;
+AddSymlinkToHaikuImage home config be : /boot/haiku/preferences : Preferences ;
+AddSymlinkToHaikuImage home config be : /boot/haiku/demos : Demos ;
 
-AddSymlinkToHaikuImage beos bin : bzip2 : bunzip2 ;
-AddSymlinkToHaikuImage beos bin : less : more ;
-AddSymlinkToHaikuImage beos bin : gzip : gunzip ;
-AddSymlinkToHaikuImage beos bin : gzip : zcat ;
-AddSymlinkToHaikuImage beos bin : zdiff : zcmp ;
-AddSymlinkToHaikuImage beos bin : unzip : zipinfo ;
-AddSymlinkToHaikuImage beos bin : gawk : awk ;
-AddSymlinkToHaikuImage beos bin : grep : egrep ;
-AddSymlinkToHaikuImage beos bin : grep : fgrep ;
-AddSymlinkToHaikuImage beos bin : vim : vi ;
-AddSymlinkToHaikuImage beos bin : vim : view ;
+AddSymlinkToHaikuImage haiku bin : bzip2 : bunzip2 ;
+AddSymlinkToHaikuImage haiku bin : less : more ;
+AddSymlinkToHaikuImage haiku bin : gzip : gunzip ;
+AddSymlinkToHaikuImage haiku bin : gzip : zcat ;
+AddSymlinkToHaikuImage haiku bin : zdiff : zcmp ;
+AddSymlinkToHaikuImage haiku bin : unzip : zipinfo ;
+AddSymlinkToHaikuImage haiku bin : gawk : awk ;
+AddSymlinkToHaikuImage haiku bin : grep : egrep ;
+AddSymlinkToHaikuImage haiku bin : grep : fgrep ;
+AddSymlinkToHaikuImage haiku bin : vim : vi ;
+AddSymlinkToHaikuImage haiku bin : vim : view ;
 
 
 # scripts and data files
 local bootScripts = Bootscript Bootscript.cd SetupEnvironment Netscript InstallerInitScript
 	InstallerFinishScript ;
 SEARCH on $(bootScripts) = [ FDirName $(HAIKU_TOP) data system boot ] ;
-AddFilesToHaikuImage beos system boot : $(bootScripts) ;
+AddFilesToHaikuImage haiku system boot : $(bootScripts) ;
 
 local logoArtwork = "HAIKU logo - white on blue - big.png"
 	"HAIKU logo - white on blue - small.png" ;
 SEARCH on $(logoArtwork) = [ FDirName $(HAIKU_TOP) data artwork ] ;
-AddFilesToHaikuImage beos etc artwork : $(logoArtwork) ;
+AddFilesToHaikuImage haiku etc artwork : $(logoArtwork) ;
 
 # Mail spell check dictionaries
 local spellFiles = words geekspeak ;
 spellFiles = $(spellFiles:G=spell) ;
 SEARCH on $(spellFiles)
 	= [ FDirName $(HAIKU_TOP) src apps mail ] ;
-AddFilesToHaikuImage beos etc word_dictionary : $(spellFiles) ;
+AddFilesToHaikuImage haiku etc word_dictionary : $(spellFiles) ;
 
 local svgFiles = "lion.svg" ;
 SEARCH on $(svgFiles)
 	= [ FDirName $(HAIKU_TOP) src tests kits interface picture ] ;
-AddFilesToHaikuImage beos etc artwork : $(svgFiles) ;
+AddFilesToHaikuImage haiku etc artwork : $(svgFiles) ;
 
 # TODO: Use data/etc/termcap or src/libs/termcap.src?
 local etcFiles = inputrc profile termcap teapot.data ;
 etcFiles = $(etcFiles:G=etc) ;
 SEARCH on $(etcFiles) = [ FDirName $(HAIKU_TOP) data etc ] ;
-AddFilesToHaikuImage beos etc : $(etcFiles) ;
+AddFilesToHaikuImage haiku etc : $(etcFiles) ;
 
 local fortuneFiles =  Art Computers Education Food Fortunes Goedel Haiku
 	Humorists Kids Law "Linux cookies" Love Magic Medicine Miscellaneous
@@ -293,37 +293,37 @@
 	Sports "Tech Support Excuses" ;
 fortuneFiles = $(fortuneFiles:G=etc!fortunes) ;
 SEARCH on $(fortuneFiles) = [ FDirName $(HAIKU_TOP) data etc fortunes ] ;
-AddFilesToHaikuImage beos etc fortunes : $(fortuneFiles) ;
+AddFilesToHaikuImage haiku etc fortunes : $(fortuneFiles) ;
 
 local fontDir = [ FDirName $(HAIKU_TOP) data etc fonts ] ;
 local psFonts = [ Glob $(fontDir)/psfonts : *.afm *.pfb ] ;
 local ttFonts = [ Glob $(fontDir)/ttfonts : *.ttf ] ;
-AddFilesToHaikuImage beos etc fonts psfonts : $(psFonts) ;
-AddFilesToHaikuImage beos etc fonts ttfonts : $(ttFonts) ;
+AddFilesToHaikuImage haiku etc fonts psfonts : $(psFonts) ;
+AddFilesToHaikuImage haiku etc fonts ttfonts : $(ttFonts) ;
 
 local kanbeDir = [ FDirName $(HAIKU_TOP) data etc KanBe ] ;
 local kanbeDefault = [ Glob $(kanbeDir)/default : *.canna *.gz ] ;
 local kanbeDic = [ Glob $(kanbeDir)/dic : *.cbp ] ;
 local kanbeDicCanna = [ Glob $(kanbeDir)/dic/canna
 	: *.cld *.ctd *.cbd *.dir ] ;
-AddFilesToHaikuImage beos etc KanBe default : $(kanbeDefault) ;
-AddFilesToHaikuImage beos etc KanBe dic : $(kanbeDic) ;
-AddFilesToHaikuImage beos etc KanBe dic canna : $(kanbeDicCanna) ;
-AddDirectoryToHaikuImage beos etc KanBe dic group ;
-AddDirectoryToHaikuImage beos etc KanBe dic user ;
+AddFilesToHaikuImage haiku etc KanBe default : $(kanbeDefault) ;
+AddFilesToHaikuImage haiku etc KanBe dic : $(kanbeDic) ;
+AddFilesToHaikuImage haiku etc KanBe dic canna : $(kanbeDicCanna) ;
+AddDirectoryToHaikuImage haiku etc KanBe dic group ;
+AddDirectoryToHaikuImage haiku etc KanBe dic user ;
 
 local keymapFiles = [ GLOB [ FDirName $(HAIKU_TOP) src data etc keymaps ]
 	: *.keymap ] ;
 keymapFiles = $(keymapFiles:BG=keymap) ;
-AddFilesToHaikuImage beos etc Keymap : $(keymapFiles) ;
-AddSymlinkToHaikuImage beos etc Keymap : Swedish : Finnish ;
-AddSymlinkToHaikuImage beos etc Keymap : Slovene : Croatian ;
-AddSymlinkToHaikuImage beos etc Keymap : US-International : Brazilian ;
+AddFilesToHaikuImage haiku etc Keymap : $(keymapFiles) ;
+AddSymlinkToHaikuImage haiku etc Keymap : Swedish : Finnish ;
+AddSymlinkToHaikuImage haiku etc Keymap : Slovene : Croatian ;
+AddSymlinkToHaikuImage haiku etc Keymap : US-International : Brazilian ;
 
 local timezones = [ FTimeZoneBinaries $(HAIKU_TIME_ZONE_SOURCES) : : true ] ;
 for timezone in $(timezones) {
 	local dir = [ on $(timezone) return $(RELATIVE_TIMEZONE_DIR) ] ;
-	AddFilesToHaikuImage beos etc timezones $(dir) : $(timezone) ;
+	AddFilesToHaikuImage haiku etc timezones $(dir) : $(timezone) ;
 }
 
 local driverSettingsFiles = <driver-settings>kernel ;
@@ -342,7 +342,7 @@
 AddFilesToHaikuImage home config settings : <settings>fresh_install ;
 
 # boot loader
-AddFilesToHaikuImage beos system : zbeos ;
+AddFilesToHaikuImage haiku system : zbeos ;
 
 # boot module links
 AddBootModuleSymlinksToHaikuImage
@@ -356,52 +356,52 @@
 ;
 
 # add-ons
-AddFilesToHaikuImage beos system add-ons accelerants
+AddFilesToHaikuImage haiku system add-ons accelerants
 	: $(BEOS_ADD_ONS_ACCELERANTS) ;
-AddFilesToHaikuImage beos system add-ons opengl
+AddFilesToHaikuImage haiku system add-ons opengl
 	: $(X86_ONLY)Mesa\ Software\ Renderer ;
-AddFilesToHaikuImage beos system add-ons Translators
+AddFilesToHaikuImage haiku system add-ons Translators
 	: $(BEOS_ADD_ONS_TRANSLATORS) ;
-AddFilesToHaikuImage beos system add-ons mail_daemon inbound_protocols : POP3 IMAP ;
-AddFilesToHaikuImage beos system add-ons mail_daemon outbound_protocols : SMTP ;
-AddFilesToHaikuImage beos system add-ons mail_daemon inbound_filters : Match\ Header Spam\ Filter R5\ Daemon\ Filter ;
-AddFilesToHaikuImage beos system add-ons mail_daemon outbound_filters : Fortune ;
-AddFilesToHaikuImage beos system add-ons mail_daemon system_filters : Inbox New\ Mail\ Notification Outbox Message\ Parser ;
-AddFilesToHaikuImage beos system add-ons media : $(BEOS_ADD_ONS_MEDIA) ;
-AddFilesToHaikuImage beos system add-ons media plugins
+AddFilesToHaikuImage haiku system add-ons mail_daemon inbound_protocols : POP3 IMAP ;
+AddFilesToHaikuImage haiku system add-ons mail_daemon outbound_protocols : SMTP ;
+AddFilesToHaikuImage haiku system add-ons mail_daemon inbound_filters : Match\ Header Spam\ Filter R5\ Daemon\ Filter ;
+AddFilesToHaikuImage haiku system add-ons mail_daemon outbound_filters : Fortune ;
+AddFilesToHaikuImage haiku system add-ons mail_daemon system_filters : Inbox New\ Mail\ Notification Outbox Message\ Parser ;
+AddFilesToHaikuImage haiku system add-ons media : $(BEOS_ADD_ONS_MEDIA) ;
+AddFilesToHaikuImage haiku system add-ons media plugins
 	: $(BEOS_ADD_ONS_MEDIA_PLUGINS) ;
-AddFilesToHaikuImage beos system add-ons Tracker : FileType-F ZipOMatic-Z ;
-AddSymlinkToHaikuImage beos system add-ons Tracker
-	: /boot/beos/preferences/Backgrounds : Background-B ;
-AddFilesToHaikuImage beos system add-ons input_server devices
+AddFilesToHaikuImage haiku system add-ons Tracker : FileType-F ZipOMatic-Z ;
+AddSymlinkToHaikuImage haiku system add-ons Tracker
+	: /boot/haiku/preferences/Backgrounds : Background-B ;
+AddFilesToHaikuImage haiku system add-ons input_server devices
 	: <input>keyboard <input>mouse <input>wacom ;
-AddFilesToHaikuImage beos system add-ons input_server filters : screen_saver ;
-AddFilesToHaikuImage beos system add-ons kernel network : stack ;
-AddFilesToHaikuImage beos system add-ons kernel network devices
+AddFilesToHaikuImage haiku system add-ons input_server filters : screen_saver ;
+AddFilesToHaikuImage haiku system add-ons kernel network : stack ;
+AddFilesToHaikuImage haiku system add-ons kernel network devices
 	: $(BEOS_NETWORK_DEVICES) ;
-AddFilesToHaikuImage beos system add-ons kernel network datalink_protocols
+AddFilesToHaikuImage haiku system add-ons kernel network datalink_protocols
 	: $(BEOS_NETWORK_DATALINK_PROTOCOLS) ;
-AddFilesToHaikuImage beos system add-ons kernel network ppp
+AddFilesToHaikuImage haiku system add-ons kernel network ppp
 	: $(BEOS_NETWORK_PPP) ;
-AddFilesToHaikuImage beos system add-ons kernel network protocols
+AddFilesToHaikuImage haiku system add-ons kernel network protocols
 	: $(BEOS_NETWORK_PROTOCOLS) ;
-AddFilesToHaikuImage beos system add-ons Print : $(BEOS_ADD_ONS_PRINT) ;
-AddFilesToHaikuImage beos system add-ons Print transport
+AddFilesToHaikuImage haiku system add-ons Print : $(BEOS_ADD_ONS_PRINT) ;
+AddFilesToHaikuImage haiku system add-ons Print transport
 	: $(BEOS_ADD_ONS_PRINT_TRANSPORT) ;
-AddFilesToHaikuImage beos system add-ons Screen\ Savers
+AddFilesToHaikuImage haiku system add-ons Screen\ Savers
 	: $(BEOS_ADD_ONS_SCREENSAVERS) ;
 
-AddFilesToHaikuImage beos system add-ons disk_systems
+AddFilesToHaikuImage haiku system add-ons disk_systems
 	: <disk_system>intel <disk_system>bfs ;
 
 AddDirectoryToHaikuImage home config add-ons Tracker ;
 AddDirectoryToHaikuImage home config add-ons Screen\ Savers ;
 AddDirectoryToHaikuImage home config add-ons Translators ;
-AddDirectoryToHaikuImage beos etc synth ;
-AddDirectoryToHaikuImage beos system add-ons input_server methods ;
+AddDirectoryToHaikuImage haiku etc synth ;
+AddDirectoryToHaikuImage haiku system add-ons input_server methods ;
 
 # optional
-AddFilesToHaikuImage optional beos system add-ons input_server methods : canna ;
+AddFilesToHaikuImage optional haiku system add-ons input_server methods : canna ;
 
 # printers
 AddDirectoryToHaikuImage home config settings printers Preview
@@ -410,7 +410,7 @@
       : home-config-settings-printers-save-as-pdf.rdef ;
 
 # licenses
-CopyDirectoryToHaikuImage beos etc
+CopyDirectoryToHaikuImage haiku etc
 	: [ FDirName $(HAIKU_TOP) data etc licenses ]
 	: licenses : -x .svn ;
 
Index: build/jam/UserBuildConfig.sample
===================================================================
--- build/jam/UserBuildConfig.sample	(revision 25223)
+++ build/jam/UserBuildConfig.sample	(working copy)
@@ -19,7 +19,7 @@
 
 # Add symlink/file (timezone and keymap settings) to the image.
 #AddSymlinkToHaikuImage home config settings
-#	: /boot/beos/etc/timezones/Europe/Paris : timezone ;
+#	: /boot/haiku/etc/timezones/Europe/Paris : timezone ;
 #AddFilesToHaikuImage home config settings : <keymap>US-International 
 #	: Key_map ;
 
Index: build/jam/PackageRules
===================================================================
--- build/jam/PackageRules	(revision 25223)
+++ build/jam/PackageRules	(working copy)
@@ -214,9 +214,9 @@
         unzip -od / install.zip
         alert "Finished installing" "Thanks"
     else
-        if [ -e /boot/beos/apps/Terminal ]
+        if [ -e /boot/haiku/apps/Terminal ]
         then
-            terminal=/boot/beos/apps/Terminal
+            terminal=/boot/haiku/apps/Terminal
         else
             terminal=`query Terminal | head -1`
         fi
Index: build/jam/NetBootArchive
===================================================================
--- build/jam/NetBootArchive	(revision 25223)
+++ build/jam/NetBootArchive	(working copy)
@@ -32,24 +32,24 @@
 
 
 # modules
-AddFilesToNetBootArchive beos system add-ons kernel bus_managers
+AddFilesToNetBootArchive haiku system add-ons kernel bus_managers
 	: $(BEOS_ADD_ONS_BUS_MANAGERS) ;
-AddFilesToNetBootArchive beos system add-ons kernel busses agp_gart
+AddFilesToNetBootArchive haiku system add-ons kernel busses agp_gart
 	: $(X86_ONLY)<agp_gart>intel ;
-AddFilesToNetBootArchive beos system add-ons kernel busses ide
+AddFilesToNetBootArchive haiku system add-ons kernel busses ide
 	: ahci generic_ide_pci $(X86_ONLY)ide_isa silicon_image_3112 ;
-AddFilesToNetBootArchive beos system add-ons kernel console : vga_text ;
-AddFilesToNetBootArchive beos system add-ons kernel file_systems
+AddFilesToNetBootArchive haiku system add-ons kernel console : vga_text ;
+AddFilesToNetBootArchive haiku system add-ons kernel file_systems
 	: $(BEOS_ADD_ONS_FILE_SYSTEMS) ;
-AddFilesToNetBootArchive beos system add-ons kernel generic
+AddFilesToNetBootArchive haiku system add-ons kernel generic
 	: block_io fast_log ide_adapter locked_pool scsi_periph ;
-AddFilesToNetBootArchive beos system add-ons kernel partitioning_systems
+AddFilesToNetBootArchive haiku system add-ons kernel partitioning_systems
 	: intel session ;
-AddFilesToNetBootArchive beos system add-ons kernel interrupt_controllers
+AddFilesToNetBootArchive haiku system add-ons kernel interrupt_controllers
 	: $(PPC_ONLY)openpic ;
 
 if $(TARGET_ARCH) = x86 {
-	AddFilesToNetBootArchive beos system add-ons kernel cpu : generic_x86 ;
+	AddFilesToNetBootArchive haiku system add-ons kernel cpu : generic_x86 ;
 }
 
 # drivers
@@ -59,7 +59,7 @@
 AddDriversToNetBootArchive net			: $(BEOS_ADD_ONS_DRIVERS_NET) ;
 
 # kernel
-AddFilesToNetBootArchive beos system : <revisioned>kernel_$(TARGET_ARCH) ;
+AddFilesToNetBootArchive haiku system : <revisioned>kernel_$(TARGET_ARCH) ;
 
 # scripts and data files
 
@@ -70,15 +70,15 @@
 	: $(driverSettingsFiles) ;
 
 # add-ons
-AddFilesToNetBootArchive beos system add-ons kernel network
+AddFilesToNetBootArchive haiku system add-ons kernel network
 	: stack ;
-AddFilesToNetBootArchive beos system add-ons kernel network devices
+AddFilesToNetBootArchive haiku system add-ons kernel network devices
 	: $(BEOS_NETWORK_DEVICES) ;
-AddFilesToNetBootArchive beos system add-ons kernel network datalink_protocols
+AddFilesToNetBootArchive haiku system add-ons kernel network datalink_protocols
 	: $(BEOS_NETWORK_DATALINK_PROTOCOLS) ;
-AddFilesToNetBootArchive beos system add-ons kernel network ppp
+AddFilesToNetBootArchive haiku system add-ons kernel network ppp
 	: $(BEOS_NETWORK_PPP) ;
-AddFilesToNetBootArchive beos system add-ons kernel network protocols
+AddFilesToNetBootArchive haiku system add-ons kernel network protocols
 	: $(BEOS_NETWORK_PROTOCOLS) ;
 
 # boot module links
Index: build/scripts/build_haiku_image
===================================================================
--- build/scripts/build_haiku_image	(revision 25223)
+++ build/scripts/build_haiku_image	(working copy)
@@ -198,7 +198,7 @@
 		$rmAttrs -f $copyrightAttrs
 		touch $copyrightAttrs
 		$addattr -f $copyrightsFile COPYRIGHTS $copyrightAttrs
-		$copyAttrs ${sPrefix}$copyrightAttrs ${tPrefix}beos/apps/AboutSystem
+		$copyAttrs ${sPrefix}$copyrightAttrs ${tPrefix}haiku/apps/AboutSystem
 	fi
 fi
 
Index: data/system/boot/SetupEnvironment
===================================================================
--- data/system/boot/SetupEnvironment	(revision 25223)
+++ data/system/boot/SetupEnvironment	(working copy)
@@ -44,13 +44,13 @@
 
 if [ "$SAFEMODE" != "yes" ]
 then
-	export PATH=.:$HOME/config/bin:/boot/common/bin:/bin:/boot/apps:/boot/preferences:/boot/beos/apps:/boot/beos/preferences:$BETOOLS
-	export LIBRARY_PATH="%A/lib:$HOME/config/lib:/boot/common/lib:/boot/beos/system/lib"
-	export ADDON_PATH="%A/add-ons:$HOME/config/add-ons:/boot/beos/system/add-ons"
+	export PATH=.:$HOME/config/bin:/boot/common/bin:/bin:/boot/apps:/boot/preferences:/boot/haiku/apps:/boot/haiku/preferences:$BETOOLS
+	export LIBRARY_PATH="%A/lib:$HOME/config/lib:/boot/common/lib:/boot/haiku/system/lib"
+	export ADDON_PATH="%A/add-ons:$HOME/config/add-ons:/boot/haiku/system/add-ons"
 else
-	export PATH=.:/boot/common/bin:/bin:/boot/apps:/boot/preferences:/boot/beos/apps:/boot/beos/preferences:$BETOOLS
-	export LIBRARY_PATH="%A/lib:/boot/common/lib:/boot/beos/system/lib"
-	export ADDON_PATH="%A/add-ons:/boot/beos/system/add-ons"
+	export PATH=.:/boot/common/bin:/bin:/boot/apps:/boot/preferences:/boot/haiku/apps:/boot/haiku/preferences:$BETOOLS
+	export LIBRARY_PATH="%A/lib:/boot/common/lib:/boot/haiku/system/lib"
+	export ADDON_PATH="%A/add-ons:/boot/haiku/system/add-ons"
 fi
 
 # media kit
Index: data/system/boot/Bootscript
===================================================================
--- data/system/boot/Bootscript	(revision 25223)
+++ data/system/boot/Bootscript	(working copy)
@@ -54,8 +54,8 @@
 exec >/dev/null 2>&1
 
 # Standard locations of boot files
-SCRIPTS=beos/system/boot
-SERVERS=beos/system/servers
+SCRIPTS=haiku/system/boot
+SERVERS=haiku/system/servers
 
 # Set up the environment
 
@@ -71,7 +71,7 @@
 fi
 
 # Sets timezone etc.
-runprog beos/bin/clockconfig
+runprog haiku/bin/clockconfig
 
 # Launch servers
 
@@ -99,18 +99,18 @@
 # Launch Terminal or consoled depending on $SAFEMODE
 if [ "$SAFEMODE" != "yes" ]; then
 	if [ -e /etc/users ]; then
-		launch beos/system/Login
+		launch haiku/system/Login
 		# nothing more
 	else
-		launch beos/system/Tracker
-		launch beos/system/Deskbar
+		launch haiku/system/Tracker
+		launch haiku/system/Deskbar
 
 		# install ProcessController in the deskbar
-		(sleep 7; /boot/beos/apps/ProcessController -deskbar) &
+		(sleep 7; /boot/haiku/apps/ProcessController -deskbar) &
 	fi
-	launch beos/apps/Terminal
+	launch haiku/apps/Terminal
 else
-	launch beos/bin/consoled
+	launch haiku/bin/consoled
 fi
 
 if [ "$SAFEMODE" != "yes" ]; then
@@ -129,7 +129,7 @@
 fi
 
 # Check for daily saving time
-launch beos/bin/dstcheck
+launch haiku/bin/dstcheck
 
 if [ "$SAFEMODE" != "yes" ]; then
 	# Start user boot script
@@ -141,9 +141,9 @@
 # Check for fresh install and register all bundled app mimetypes
 FRESH_INSTALL_INDICATOR_FILE=$HOME/config/settings/fresh_install
 if [ -e $FRESH_INSTALL_INDICATOR_FILE ]; then
-#	mimeset -all -f /boot/beos/apps
-#	mimeset -all -f /boot/beos/preferences
-#	mimeset -all -f /boot/beos/system/servers
+#	mimeset -all -f /boot/haiku/apps
+#	mimeset -all -f /boot/haiku/preferences
+#	mimeset -all -f /boot/haiku/system/servers
 #	mimeset -all -f /boot/apps
 	rm $FRESH_INSTALL_INDICATOR_FILE
 fi
Index: data/system/boot/Bootscript.cd
===================================================================
--- data/system/boot/Bootscript.cd	(revision 25223)
+++ data/system/boot/Bootscript.cd	(working copy)
@@ -72,15 +72,15 @@
 
 # Launch Terminal or consoled depending on $SAFEMODE
 if [ "$SAFEMODE" != "yes" ]; then
-	if [ -x /boot/beos/apps/Installer ]; then
-		/boot/beos/apps/Installer
-		#/boot/beos/apps/Terminal -x /boot/beos/apps/Installer
+	if [ -x /boot/haiku/apps/Installer ]; then
+		/boot/haiku/apps/Installer
+		#/boot/haiku/apps/Terminal -x /boot/haiku/apps/Installer
 	else
-		/boot/beos/apps/Terminal
+		/boot/haiku/apps/Terminal
 	fi
-	#launch beos/apps/Terminal
+	#launch haiku/apps/Terminal
 else
-	launch beos/bin/consoled
+	launch haiku/bin/consoled
 fi
 
 # sync disks
Index: src/preferences/network_old/NetworkWindow.cpp
===================================================================
--- src/preferences/network_old/NetworkWindow.cpp	(revision 25223)
+++ src/preferences/network_old/NetworkWindow.cpp	(working copy)
@@ -346,7 +346,7 @@
 			argc  = 1;
 			arg_v = (const char **)malloc(sizeof(char *) * (argc + 1));
 			
-			arg_v[0] = strdup("/boot/beos/system/servers/net_server");
+			arg_v[0] = strdup("/boot/haiku/system/servers/net_server");
 			arg_v[1] = NULL;
 			
 			thread = load_image(argc,arg_v,(const char **)environ); 
Index: src/preferences/time/ZoneView.cpp
===================================================================
--- src/preferences/time/ZoneView.cpp	(revision 25223)
+++ src/preferences/time/ZoneView.cpp	(working copy)
@@ -360,12 +360,12 @@
 		tzLink.SetTo(path.Path(), true);
 
 		if (tzLink.InitCheck() != B_OK) {// link is broken
-			tzLink.SetTo("/boot/beos/etc/timezones/Pacific/fiji");
+			tzLink.SetTo("/boot/haiku/etc/timezones/Pacific/fiji");
 			// do something like set to a default GMT???
 		}
  	} else {
  		// set tzlink to a default
- 		tzLink.SetTo("/boot/beos/etc/timezones/EST");
+ 		tzLink.SetTo("/boot/haiku/etc/timezones/EST");
  	}
 #endif
 	// we need something in the current zone
Index: src/preferences/sounds/HWindow.cpp
===================================================================
--- src/preferences/sounds/HWindow.cpp	(revision 25223)
+++ src/preferences/sounds/HWindow.cpp	(working copy)
@@ -330,7 +330,7 @@
 		menu->AddItem(new BMenuItem(path.Leaf(), msg), 0);
 	}
 	
-	BPath path("/boot/beos/etc/sounds");
+	BPath path("/boot/haiku/etc/sounds");
 	status_t err = B_OK;
 	BDirectory dir( path.Path() );
 	BEntry entry;
Index: src/tests/add-ons/kernel/kernelland_emu.cpp
===================================================================
--- src/tests/add-ons/kernel/kernelland_emu.cpp	(revision 25223)
+++ src/tests/add-ons/kernel/kernelland_emu.cpp	(working copy)
@@ -32,7 +32,7 @@
 //#define TRACE(x) printf x
 
 static const char *gModuleDirs[] = {
-	"distro/x86.R1/beos/system/add-ons/userland",
+	"distro/x86.R1/haiku/system/add-ons/userland",
 	NULL
 };
 
Index: src/tests/servers/registrar/run_haiku_registrar.cpp
===================================================================
--- src/tests/servers/registrar/run_haiku_registrar.cpp	(revision 25223)
+++ src/tests/servers/registrar/run_haiku_registrar.cpp	(working copy)
@@ -26,7 +26,7 @@
 	team_info teamInfo;
 	int32 cookie = 0;
 	while (get_next_team_info(&cookie, &teamInfo) == B_OK) {
-		if (!strncmp(teamInfo.args, "/boot/beos/", 11)) {
+		if (!strncmp(teamInfo.args, "/boot/haiku/", 11)) {
 			// this is a system component and not worth to investigate
 			continue;
 		}
Index: src/tests/kits/app/bmessage/MessageRefItemTest.h
===================================================================
--- src/tests/kits/app/bmessage/MessageRefItemTest.h	(revision 25223)
+++ src/tests/kits/app/bmessage/MessageRefItemTest.h	(working copy)
@@ -122,7 +122,7 @@
 	static entry_ref Test1()
 	{
 		entry_ref ref;
-		get_ref_for_path("/boot/beos/apps/camera", &ref);
+		get_ref_for_path("/boot/haiku/apps/camera", &ref);
 		return ref;
 	}
 	static entry_ref Test2()
Index: src/tests/kits/interface/WidthBufferTest.cpp
===================================================================
--- src/tests/kits/interface/WidthBufferTest.cpp	(revision 25223)
+++ src/tests/kits/interface/WidthBufferTest.cpp	(working copy)
@@ -64,7 +64,7 @@
 int32
 App::TesterFunc()
 {
-	FILE *file = fopen("/boot/beos/etc/termcap", "r");
+	FILE *file = fopen("/boot/haiku/etc/termcap", "r");
 	if (file != NULL) {
 		char buffer[512];
 		while (fgets(buffer, 512, file)) {
Index: src/tests/kits/interface/picture/PictureTest.cpp
===================================================================
--- src/tests/kits/interface/picture/PictureTest.cpp	(revision 25223)
+++ src/tests/kits/interface/picture/PictureTest.cpp	(working copy)
@@ -7,14 +7,14 @@
 
 #include "SVGViewView.h"
 
-class Svg2PictureWindow : public BWindow {
-public:
-	Svg2PictureWindow(BRect frame, const char *filename)
-		:   BWindow(frame, "Svg2Picture", B_TITLED_WINDOW, 0) {
-        
-        	BView *view = new Svg2PictureView(Bounds(), filename);
-        	AddChild(view);
-	}
+class Svg2PictureWindow : public BWindow {
+public:
+	Svg2PictureWindow(BRect frame, const char *filename)
+		:   BWindow(frame, "Svg2Picture", B_TITLED_WINDOW, 0) {
+        
+        	BView *view = new Svg2PictureView(Bounds(), filename);
+        	AddChild(view);
+	}
 };
 
 class OriginalView : public BBox {
@@ -154,7 +154,7 @@
 				"BPicture test", B_TITLED_WINDOW,
 				B_NOT_RESIZABLE|B_NOT_ZOOMABLE|B_QUIT_ON_WINDOW_CLOSE);
 	
-	BWindow *svgWindow = new Svg2PictureWindow(BRect(300, 300, 600, 600), "/boot/beos/etc/artwork/lion.svg");
+	BWindow *svgWindow = new Svg2PictureWindow(BRect(300, 300, 600, 600), "/boot/haiku/etc/artwork/lion.svg");
 	
 	
 	BRect rect(pictureWindow->Bounds());
Index: src/tests/kits/midi/midi_player_replacement/MidiPlayerView.h
===================================================================
--- src/tests/kits/midi/midi_player_replacement/MidiPlayerView.h	(revision 25223)
+++ src/tests/kits/midi/midi_player_replacement/MidiPlayerView.h	(working copy)
@@ -54,7 +54,7 @@
 //--------------
 //--------------
 //--------------
-#define BEOS_SYNTH_DIRECTORY "/boot/beos/etc/synth/"
+#define BEOS_SYNTH_DIRECTORY "/boot/haiku/etc/synth/"
 //--------------
 
 //----------------------------------------------------------
Index: src/tests/kits/storage/FindDirectoryTest.cpp
===================================================================
--- src/tests/kits/storage/FindDirectoryTest.cpp	(revision 25223)
+++ src/tests/kits/storage/FindDirectoryTest.cpp	(working copy)
@@ -180,49 +180,49 @@
 		}
 		// BeOS directories.  These are mostly accessed read-only.
 		case B_BEOS_DIRECTORY:
-			error = path.SetTo("/boot/beos");
+			error = path.SetTo("/boot/haiku");
 			break;
 		case B_BEOS_SYSTEM_DIRECTORY:
-			error = path.SetTo("/boot/beos/system");
+			error = path.SetTo("/boot/haiku/system");
 			break;
 		case B_BEOS_ADDONS_DIRECTORY:
-			error = path.SetTo("/boot/beos/system/add-ons");
+			error = path.SetTo("/boot/haiku/system/add-ons");
 			break;
 		case B_BEOS_BOOT_DIRECTORY:
-			error = path.SetTo("/boot/beos/system/boot");
+			error = path.SetTo("/boot/haiku/system/boot");
 			break;
 		case B_BEOS_FONTS_DIRECTORY:
-			error = path.SetTo("/boot/beos/etc/fonts");
+			error = path.SetTo("/boot/haiku/etc/fonts");
 			break;
 		case B_BEOS_LIB_DIRECTORY:
-			error = path.SetTo("/boot/beos/system/lib");
+			error = path.SetTo("/boot/haiku/system/lib");
 			break;
  		case B_BEOS_SERVERS_DIRECTORY:
-			error = path.SetTo("/boot/beos/system/servers");
+			error = path.SetTo("/boot/haiku/system/servers");
 			break;
 		case B_BEOS_APPS_DIRECTORY:
-			error = path.SetTo("/boot/beos/apps");
+			error = path.SetTo("/boot/haiku/apps");
 			break;
 		case B_BEOS_BIN_DIRECTORY:
-			error = path.SetTo("/boot/beos/bin");
+			error = path.SetTo("/boot/haiku/bin");
 			break;
 		case B_BEOS_ETC_DIRECTORY:
-			error = path.SetTo("/boot/beos/etc");
+			error = path.SetTo("/boot/haiku/etc");
 			break;
 		case B_BEOS_DOCUMENTATION_DIRECTORY:
-			error = path.SetTo("/boot/beos/documentation");
+			error = path.SetTo("/boot/haiku/documentation");
 			break;
 		case B_BEOS_PREFERENCES_DIRECTORY:
-			error = path.SetTo("/boot/beos/preferences");
+			error = path.SetTo("/boot/haiku/preferences");
 			break;
 		case B_BEOS_TRANSLATORS_DIRECTORY:
-			error = path.SetTo("/boot/beos/system/add-ons/Translators");
+			error = path.SetTo("/boot/haiku/system/add-ons/Translators");
 			break;
 		case B_BEOS_MEDIA_NODES_DIRECTORY:
-			error = path.SetTo("/boot/beos/system/add-ons/media");
+			error = path.SetTo("/boot/haiku/system/add-ons/media");
 			break;
 		case B_BEOS_SOUNDS_DIRECTORY:
-			error = path.SetTo("/boot/beos/etc/sounds");
+			error = path.SetTo("/boot/haiku/etc/sounds");
 			break;
 		// Common directories, shared among all users.
 		case B_COMMON_DIRECTORY:
Index: src/tests/kits/storage/MimeTypeTest.cpp
===================================================================
--- src/tests/kits/storage/MimeTypeTest.cpp	(revision 25223)
+++ src/tests/kits/storage/MimeTypeTest.cpp	(working copy)
@@ -66,8 +66,8 @@
 static const char *applicationSupertype	= "application";
 
 // Application Paths
-static const char *testApp				= "/boot/beos/apps/SoundRecorder";
-static const char *testApp2				= "/boot/beos/apps/CDPlayer";
+static const char *testApp				= "/boot/haiku/apps/SoundRecorder";
+static const char *testApp2				= "/boot/haiku/apps/CDPlayer";
 static const char *fakeTestApp			= "/__this_isn't_likely_to_exist__";
 
 // BMessage field names
@@ -3236,7 +3236,7 @@
 							B_MINI_ICON) == B_OK);
 	// app hint
 	entry_ref appHintRef;
-	CHK(get_ref_for_path("/boot/beos/apps/StyledEdit", &appHintRef) == B_OK);
+	CHK(get_ref_for_path("/boot/haiku/apps/StyledEdit", &appHintRef) == B_OK);
 	CHK(type.SetAppHint(&appHintRef) == B_OK);
 	// sniffer rule
 	const char *snifferRule = "0.5 [0:0] ('ARGH')";
@@ -3334,7 +3334,7 @@
 							B_MINI_ICON) == B_OK);
 	// app hint
 	entry_ref appHintRef2;
-	CHK(get_ref_for_path("/boot/beos/apps/NetPositive", &appHintRef2) == B_OK);
+	CHK(get_ref_for_path("/boot/haiku/apps/NetPositive", &appHintRef2) == B_OK);
 	CHK(type.SetAppHint(&appHintRef2) == B_OK);
 	// sniffer rule
 	const char *snifferRule2 = "0.7 [0:5] ('YEAH!')";
Index: src/tests/kits/storage/DirectoryTest.cpp
===================================================================
--- src/tests/kits/storage/DirectoryTest.cpp	(revision 25223)
+++ src/tests/kits/storage/DirectoryTest.cpp	(working copy)
@@ -619,7 +619,7 @@
 	CPPUNIT_ASSERT( dir.IsRootDirectory() == true );
 	//
 	NextSubTest();
-	CPPUNIT_ASSERT( dir.SetTo("/boot/beos") == B_OK );
+	CPPUNIT_ASSERT( dir.SetTo("/boot/haiku") == B_OK );
 	CPPUNIT_ASSERT( dir.InitCheck() == B_OK );
 	CPPUNIT_ASSERT( dir.IsRootDirectory() == false );
 	//
Index: src/tests/kits/translation/TranslationUtilsTest.cpp
===================================================================
--- src/tests/kits/translation/TranslationUtilsTest.cpp	(revision 25223)
+++ src/tests/kits/translation/TranslationUtilsTest.cpp	(working copy)
@@ -357,7 +357,7 @@
 	BTranslatorRoster *proster = new BTranslatorRoster();
 	CPPUNIT_ASSERT(proster);
 	CPPUNIT_ASSERT(proster->AddTranslators(
-		"/boot/beos/system/add-ons/Translators/PPMTranslator") == B_OK);
+		"/boot/haiku/system/add-ons/Translators/PPMTranslator") == B_OK);
 	CPPUNIT_ASSERT(BTranslationUtils::AddTranslationItems(pmenu,
 		B_TRANSLATOR_BITMAP, NULL, NULL, NULL, proster) == B_OK);
 	CPPUNIT_ASSERT(pmenu->CountItems() == 1);
Index: src/apps/processcontroller/PCWorld.cpp
===================================================================
--- src/apps/processcontroller/PCWorld.cpp	(revision 25223)
+++ src/apps/processcontroller/PCWorld.cpp	(working copy)
@@ -150,7 +150,7 @@
 			} while (be_roster->IsRunning(kTrackerSig) && k-- > 0);
 		}
 		remove("/boot/home/config/settings/Tracker/tracker_shelf");
-		launch(kTrackerSig, "/boot/beos/system/Tracker");
+		launch(kTrackerSig, "/boot/haiku/system/Tracker");
 	} else if (argc == 2 && strcmp(argv[1], "-deskbar") == 0) {
 		BDeskbar deskbar;
 		if (!gInDeskbar && !deskbar.HasItem(kDeskbarItemName))
Index: src/apps/processcontroller/ProcessController.cpp
===================================================================
--- src/apps/processcontroller/ProcessController.cpp	(revision 25223)
+++ src/apps/processcontroller/ProcessController.cpp	(working copy)
@@ -311,21 +311,21 @@
 			break;
 
 		case 'Trac':
-			launch(kTrackerSig, "/boot/beos/system/Tracker");
+			launch(kTrackerSig, "/boot/haiku/system/Tracker");
 			break;
 
 		case 'Dbar':
-			launch(kDeskbarSig, "/boot/beos/system/Deskbar");
+			launch(kDeskbarSig, "/boot/haiku/system/Deskbar");
 			break;
 		
 		case 'Term':
-			launch(kTerminalSig, "/boot/beos/apps/Terminal");
+			launch(kTerminalSig, "/boot/haiku/apps/Terminal");
 			break;
 
 		case 'AlDb':
 		{
 			if (!be_roster->IsRunning(kDeskbarSig))
-				launch(kDeskbarSig, "/boot/beos/system/Deskbar");
+				launch(kDeskbarSig, "/boot/haiku/system/Deskbar");
 			BDeskbar deskbar;
 			if (gInDeskbar || deskbar.HasItem (kDeskbarItemName))
 				deskbar.RemoveItem (kDeskbarItemName);
Index: src/apps/mediaconverter/MediaConverterWindow.cpp
===================================================================
--- src/apps/mediaconverter/MediaConverterWindow.cpp	(revision 25223)
+++ src/apps/mediaconverter/MediaConverterWindow.cpp	(working copy)
@@ -343,7 +343,7 @@
 
 	BString string, string2;
 
-	BEntry entry("/boot/beos/apps/MediaPlayer", true);
+	BEntry entry("/boot/haiku/apps/MediaPlayer", true);
 	char buffer[40];
 	char buffer2[B_PATH_NAME_LENGTH];
 	char *argv[3];
Index: src/apps/installer/FSUtils.cpp
===================================================================
--- src/apps/installer/FSUtils.cpp	(revision 25223)
+++ src/apps/installer/FSUtils.cpp	(working copy)
@@ -467,7 +467,7 @@
 	bool requireOverride = true;
 
 	if (DirectoryMatches(entry, B_BEOS_DIRECTORY))
-		warning = "If you %s the beos folder, you won't be able to "
+		warning = "If you %s the haiku folder, you won't be able to "
 			"boot " OS_NAME "! Are you sure you want to do this? To %s the folder "
 			"anyway, hold down the Shift key and click \"Do it\".";
 	else if (DirectoryMatchesOrContains(entry, B_BEOS_SYSTEM_DIRECTORY))
@@ -3312,7 +3312,7 @@
 
 WellKnowEntryList::WellKnowEntryList()
 {
-	AddOne(B_BEOS_DIRECTORY, "beos");
+	AddOne(B_BEOS_DIRECTORY, "haiku");
 	AddOne((directory_which)B_BOOT_DISK, "/boot", "boot");
 	AddOne(B_USER_DIRECTORY, "home");
 	AddOne(B_BEOS_SYSTEM_DIRECTORY, "system");
Index: src/system/kernel/device_manager/device_manager_private.h
===================================================================
--- src/system/kernel/device_manager/device_manager_private.h	(revision 25223)
+++ src/system/kernel/device_manager/device_manager_private.h	(working copy)
@@ -23,7 +23,7 @@
 
 // driver registration directories
 #define PNP_DIR
-#define SYSTEM_DRIVER_REGISTRATION "/boot/beos/system/add-ons/kernel/"PNP_DIR"registration/"
+#define SYSTEM_DRIVER_REGISTRATION "/boot/haiku/system/add-ons/kernel/"PNP_DIR"registration/"
 #define COMMON_DRIVER_REGISTRATION "/boot/home/config/add-ons/kernel/"PNP_DIR"registration/"
 
 // info about ID generator
Index: src/system/kernel/module.cpp
===================================================================
--- src/system/kernel/module.cpp	(revision 25223)
+++ src/system/kernel/module.cpp	(working copy)
@@ -958,7 +958,7 @@
 					image->name)) != NULL) {
 			// even if strlcpy() is used here, it's by no means safe
 			// against buffer overflows
-			size_t length = strlcpy(path, "/boot/beos/system/add-ons/kernel/",
+			size_t length = strlcpy(path, "/boot/haiku/system/add-ons/kernel/",
 				sizeof(path));
 			strlcpy(path + length, name, strlen(image->name)
 				+ 1 + (suffix - name));
Index: src/system/kernel/fs/devfs.cpp
===================================================================
--- src/system/kernel/fs/devfs.cpp	(revision 25223)
+++ src/system/kernel/fs/devfs.cpp	(working copy)
@@ -493,7 +493,7 @@
 get_priority(const char *path)
 {
 	// TODO: use find_directory()
-	const char *kPaths[] = {"/boot/beos", "/boot/common", "/boot/home", NULL};
+	const char *kPaths[] = {"/boot/haiku", "/boot/common", "/boot/home", NULL};
 
 	for (int32 i = 0; kPaths[i] != NULL; i++) {
 		if (!strncmp(kPaths[i], path, strlen(kPaths[i])))
@@ -2839,7 +2839,7 @@
 		if (!image->is_module && image->id >= 0) {
 			// fake an absolute path
 			char path[B_PATH_NAME_LENGTH];
-			strlcpy(path, "/boot/beos/system/add-ons/kernel/", sizeof(path));
+			strlcpy(path, "/boot/haiku/system/add-ons/kernel/", sizeof(path));
 			strlcat(path, image->name, sizeof(path));
 
 			// try to add the driver
Index: src/system/kernel/fs/vfs_boot.cpp
===================================================================
--- src/system/kernel/fs/vfs_boot.cpp	(revision 25223)
+++ src/system/kernel/fs/vfs_boot.cpp	(working copy)
@@ -44,9 +44,9 @@
 	const char *path;
 	const char *target;
 } sPredefinedLinks[] = {
-	{"/system", "/boot/beos/system"},
-	{"/bin", "/boot/beos/bin"},
-	{"/etc", "/boot/beos/etc"},
+	{"/system", "/boot/haiku/system"},
+	{"/bin", "/boot/haiku/bin"},
+	{"/etc", "/boot/haiku/etc"},
 	{"/var", "/boot/var"},
 	{"/tmp", "/boot/var/tmp"},
 	{NULL}
Index: src/system/kernel/vm/vm_tests.c
===================================================================
--- src/system/kernel/vm/vm_tests.c	(revision 25223)
+++ src/system/kernel/vm/vm_tests.c	(working copy)
@@ -198,7 +198,7 @@
 //		char *blah;
 		int fd;
 
-		fd = _kern_open("/boot/beos/system/kernel_" OBOS_ARCH, 0);
+		fd = _kern_open("/boot/haiku/system/kernel_" OBOS_ARCH, 0);
 
 		rid = vm_map_file(vm_kernel_address_space_id(), "mmap_test", &ptr, B_ANY_KERNEL_ADDRESS,
 			B_PAGE_SIZE, B_KERNEL_READ_AREA | B_KERNEL_WRITE_AREA, REGION_NO_PRIVATE_MAP, "/boot/kernel", 0);
Index: src/system/kernel/main.c
===================================================================
--- src/system/kernel/main.c	(revision 25223)
+++ src/system/kernel/main.c	(working copy)
@@ -288,7 +288,7 @@
 
 	// start the init process
 	{
-		const char *args[] = {"/bin/sh", "/boot/beos/system/boot/Bootscript",
+		const char *args[] = {"/bin/sh", "/boot/haiku/system/boot/Bootscript",
 			NULL};
 		int32 argc = 2;
 		thread_id thread;
Index: src/system/kernel/team.cpp
===================================================================
--- src/system/kernel/team.cpp	(revision 25223)
+++ src/system/kernel/team.cpp	(working copy)
@@ -1117,7 +1117,7 @@
 		// the arguments are already on the user stack, we no longer need them in this form
 
 	// ToDo: don't use fixed paths!
-	err = elf_load_user_image("/boot/beos/system/runtime_loader", team, 0, &entry);
+	err = elf_load_user_image("/boot/haiku/system/runtime_loader", team, 0, &entry);
 	if (err < B_OK) {
 		// Luckily, we don't have to clean up the mess we created - that's
 		// done for us by the normal team deletion process
Index: src/system/boot/platform/bios_ia32/stage1.bin
===================================================================
Cannot display: file marked as a binary type.
svn:mime-type = application/octet-stream
Index: src/system/boot/loader/loader.cpp
===================================================================
--- src/system/boot/loader/loader.cpp	(revision 25223)
+++ src/system/boot/loader/loader.cpp	(working copy)
@@ -24,11 +24,11 @@
 #endif
 
 #define KERNEL_IMAGE	"kernel_" BOOT_ARCH
-#define KERNEL_PATH		"beos/system/" KERNEL_IMAGE
+#define KERNEL_PATH		"haiku/system/" KERNEL_IMAGE
 
 
 static const char *sPaths[] = {
-	"beos/system/add-ons/kernel",
+	"haiku/system/add-ons/kernel",
 	"home/config/add-ons/kernel",
 	NULL
 };
Index: src/system/runtime_loader/runtime_loader.c
===================================================================
--- src/system/runtime_loader/runtime_loader.c	(revision 25223)
+++ src/system/runtime_loader/runtime_loader.c	(working copy)
@@ -65,22 +65,22 @@
 				":/bin"
 				":/boot/apps"
 				":/boot/preferences"
-				":/boot/beos/apps"
-				":/boot/beos/preferences"
+				":/boot/haiku/apps"
+				":/boot/haiku/preferences"
 				":/boot/develop/tools/gnupro/bin";
 
 		case B_LIBRARY_IMAGE:
 			return "%A/lib"
 				":/boot/home/config/lib"
 					// TODO: Remove!
-				":/boot/common/lib:/boot/beos/system/lib";
+				":/boot/common/lib:/boot/haiku/system/lib";
 
 		case B_ADD_ON_IMAGE:
 			return "%A/add-ons"
 				":/boot/home/config/add-ons"
 					// TODO: Remove!
 				":/boot/common/add-ons"
-				":/boot/beos/system/add-ons";
+				":/boot/haiku/system/add-ons";
 
 		default:
 			return NULL;
Index: src/system/libroot/os/find_directory.c
===================================================================
--- src/system/libroot/os/find_directory.c	(revision 25223)
+++ src/system/libroot/os/find_directory.c	(working copy)
@@ -30,10 +30,7 @@
 
 /* Haiku system directories */
 
-/* os root dir; just stick to 'beos' for now */
-#define OS "beos"
-//#define OS "haiku" // :)
-//#define OS "os"
+#define OS "haiku"
 
 static const char *os_dirs[] = {
 	OS,										// B_BEOS_DIRECTORY
Index: src/add-ons/mail_daemon/outbound_filters/fortune/ConfigView.cpp
===================================================================
--- src/add-ons/mail_daemon/outbound_filters/fortune/ConfigView.cpp	(revision 25223)
+++ src/add-ons/mail_daemon/outbound_filters/fortune/ConfigView.cpp	(working copy)
@@ -27,7 +27,7 @@
 
 	BRect rect(5,4,250,25);
 	rect.bottom = rect.top - 2 + itemHeight;
-	BMailFileConfigView *fview = new BMailFileConfigView(MDR_DIALECT_CHOICE ("Fortune File:","予言ファイル:"),"fortune_file",false,"/boot/beos/etc/fortunes/default",B_FILE_NODE);
+	BMailFileConfigView *fview = new BMailFileConfigView(MDR_DIALECT_CHOICE ("Fortune File:","予言ファイル:"),"fortune_file",false,"/boot/haiku/etc/fortunes/default",B_FILE_NODE);
 	AddChild(fview);
 	
 	rect.top = rect.bottom + 8;
@@ -44,7 +44,7 @@
 {
 	BString path = archive->FindString("fortune_file");
 	if (path == B_EMPTY_STRING)
-		path = "/boot/beos/etc/fortunes/default";
+		path = "/boot/haiku/etc/fortunes/default";
 	
 	if (BMailFileConfigView *control = (BMailFileConfigView *)FindView("fortune_file"))
 		control->SetTo(archive,NULL);
Index: src/add-ons/print/drivers/pdf/source/PrinterSetupWindow.cpp
===================================================================
--- src/add-ons/print/drivers/pdf/source/PrinterSetupWindow.cpp	(revision 25223)
+++ src/add-ons/print/drivers/pdf/source/PrinterSetupWindow.cpp	(working copy)
@@ -140,7 +140,7 @@
 	BDirectory	Folder;
 	BEntry		entry;
 	
-	Folder.SetTo ("/boot/beos/etc/bubblejet");
+	Folder.SetTo ("/boot/haiku/etc/bubblejet");
 	if (Folder.InitCheck() != B_OK)
 		return;
 		
Index: src/bin/make/config.h
===================================================================
--- src/bin/make/config.h	(revision 25223)
+++ src/bin/make/config.h	(working copy)
@@ -2,7 +2,7 @@
 /* config.h.  Generated by configure.  */
 /* config.h.in.  Generated from configure.in by autoheader.  */
 
-#define LOCALEDIR	"/boot/beos/etc/local/"
+#define LOCALEDIR	"/boot/haiku/etc/local/"
 #define LIBDIR		"/boot/develop/lib/"
 #define INCLUDEDIR	"/boot/develop/headers/"
 
Index: src/bin/network/wget/src/config.h
===================================================================
--- src/bin/network/wget/src/config.h	(revision 25223)
+++ src/bin/network/wget/src/config.h	(working copy)
@@ -251,7 +251,7 @@
 #define HAVE_WORKING_FNMATCH_H 1
 
 /* Define to be the name of the operating system. */
-#define OS_TYPE "beos"
+#define OS_TYPE "haiku"
 
 /* Define to the address where bug reports for this package should be sent. */
 #define PACKAGE_BUGREPORT ""
Index: src/bin/desklink/desklink.cpp
===================================================================
--- src/bin/desklink/desklink.cpp	(revision 25223)
+++ src/bin/desklink/desklink.cpp	(working copy)
@@ -165,7 +165,7 @@
 		// launch the media player app
 		if (LaunchBySig("application/x-vnd.Haiku-MediaPlayer") == B_OK
 			|| LaunchBySig("application/x-vnd.Be.MediaPlayer") == B_OK
-			|| LaunchByPath("/boot/beos/apps/MediaPlayer") == B_OK)
+			|| LaunchByPath("/boot/haiku/apps/MediaPlayer") == B_OK)
 			break;
 
 		(new BAlert("desklink", "Couldn't launch MediaPlayer", "OK"))->Go();
Index: src/libs/ncurses/include/ncurses_cfg.h
===================================================================
--- src/libs/ncurses/include/ncurses_cfg.h	(revision 25223)
+++ src/libs/ncurses/include/ncurses_cfg.h	(working copy)
@@ -46,7 +46,7 @@
 #ifndef NC_CONFIG_H
 #define NC_CONFIG_H
 
-#define SYSTEM_NAME "beos"
+#define SYSTEM_NAME "haiku"
 #define CC_HAS_PROTOS 1
 #define HAVE_LONG_FILE_NAMES 1
 #define MIXEDCASE_FILENAMES 1
Index: src/servers/app/FontManager.cpp
===================================================================
--- src/servers/app/FontManager.cpp	(revision 25223)
+++ src/servers/app/FontManager.cpp	(working copy)
@@ -318,11 +318,11 @@
 	// TODO: load them for real, and use these as a fallback
 
 	_AddDefaultMapping("Bitstream Vera Sans", "Roman",
-		"/boot/beos/etc/fonts/ttfonts/Vera.ttf");
+		"/boot/haiku/etc/fonts/ttfonts/Vera.ttf");
 	_AddDefaultMapping("Bitstream Vera Sans", "Bold",
-		"/boot/beos/etc/fonts/ttfonts/VeraBd.ttf");
+		"/boot/haiku/etc/fonts/ttfonts/VeraBd.ttf");
 	_AddDefaultMapping("Bitstream Vera Sans Mono", "Roman",
-		"/boot/beos/etc/fonts/ttfonts/VeraMono.ttf");
+		"/boot/haiku/etc/fonts/ttfonts/VeraMono.ttf");
 
 	return false;
 }
Index: src/servers/debug/DebugServer.cpp
===================================================================
--- src/servers/debug/DebugServer.cpp	(revision 25223)
+++ src/servers/debug/DebugServer.cpp	(working copy)
@@ -42,7 +42,7 @@
 
 // paths to the apps used for debugging
 static const char *kConsoledPath	= "/bin/consoled";
-static const char *kTerminalPath	= "/boot/beos/apps/Terminal";
+static const char *kTerminalPath	= "/boot/haiku/apps/Terminal";
 static const char *kGDBPath			= "/bin/gdb";
 
 
Index: src/servers/registrar/TRoster.cpp
===================================================================
--- src/servers/registrar/TRoster.cpp	(revision 25223)
+++ src/servers/registrar/TRoster.cpp	(working copy)
@@ -78,10 +78,10 @@
 
 //! Applications living in this tree are considered "vital system apps".
 static const char *const kVitalSystemAppPathPrefix
-	= "/boot/beos/system/servers";
+	= "/boot/haiku/system/servers";
 
 //! Applications living in this tree are considered "system apps".
-static const char *const kSystemAppPathPrefix = "/boot/beos/system";
+static const char *const kSystemAppPathPrefix = "/boot/haiku/system";
 
 // get_default_roster_settings_file
 /*!	\brief Returns the path to the default roster settings.
Index: src/kits/media/DormantNodeManager.cpp
===================================================================
--- src/kits/media/DormantNodeManager.cpp	(revision 25223)
+++ src/kits/media/DormantNodeManager.cpp	(working copy)
@@ -33,7 +33,7 @@
  * It handles loading/unloading of dormant nodes.
  *
  * Dormant media nodes can be instantiated on demand. The reside on harddisk in the
- * directories /boot/beos/system/add-ons/media and /boot/home/config/add-ons/media
+ * directories /boot/haiku/system/add-ons/media and /boot/home/config/add-ons/media
  * Multiple media nodes can be included in one file, they can be accessed using the 
  * BMediaAddOn that each file implements.
  * The BMediaAddOn allows getting a list of supported flavors. Each flavor represents
Index: src/kits/tracker/Tests.cpp
===================================================================
--- src/kits/tracker/Tests.cpp	(revision 25223)
+++ src/kits/tracker/Tests.cpp	(working copy)
@@ -55,7 +55,7 @@
 
 const char *pathsToSearch[] = {
 //	"/boot/home/config/settings/NetPositive/Bookmarks/",
-	"/boot/beos",
+	"/boot/haiku",
 	"/boot/apps",
 	"/boot/home",
 	0
Index: src/kits/tracker/FSUtils.cpp
===================================================================
--- src/kits/tracker/FSUtils.cpp	(revision 25223)
+++ src/kits/tracker/FSUtils.cpp	(working copy)
@@ -467,7 +467,7 @@
 	bool requireOverride = true;
 
 	if (DirectoryMatches(entry, B_BEOS_DIRECTORY))
-		warning = "If you %s the beos folder, you won't be able to "
+		warning = "If you %s the haiku folder, you won't be able to "
 			"boot " OS_NAME "! Are you sure you want to do this? To %s the folder "
 			"anyway, hold down the Shift key and click \"Do it\".";
 	else if (DirectoryMatchesOrContains(entry, B_BEOS_SYSTEM_DIRECTORY))
@@ -3404,7 +3404,7 @@
 
 WellKnowEntryList::WellKnowEntryList()
 {
-	AddOne(B_BEOS_DIRECTORY, "beos");
+	AddOne(B_BEOS_DIRECTORY, "haiku");
 	AddOne((directory_which)B_BOOT_DISK, "/boot", "boot");
 	AddOne(B_USER_DIRECTORY, "home");
 	AddOne(B_BEOS_SYSTEM_DIRECTORY, "system");
Index: src/kits/tracker/TrackerInitialState.cpp
===================================================================
--- src/kits/tracker/TrackerInitialState.cpp	(revision 25223)
+++ src/kits/tracker/TrackerInitialState.cpp	(working copy)
@@ -460,7 +460,7 @@
 	// make the large Haiku Logo the default background
 
 //	BPath path;
-	BPath path("/boot/beos/etc/artwork");
+	BPath path("/boot/haiku/etc/artwork");
 //	FSFindTrackerSettingsDir(&path, false);
 //	path.Append(kDefaultFolderTemplate);
 

Index: src/system/boot/platform/bios_ia32/stage1.S
===================================================================
--- src/system/boot/platform/bios_ia32/stage1.S	(revision 25223)
+++ src/system/boot/platform/bios_ia32/stage1.S	(working copy)
@@ -5,7 +5,7 @@
 ; partitions. The offset of the partition in 512 byte blocks must be written at
 ; position PARTITION_OFFSET_OFFSET (32 bit little endian; makebootable does
 ; that) or otherwise the code can't find the partition.
 ; The partition must be a BFS formatted. The file "beos/system/zbeos"
 ; (the stage 2 boot loader) loaded into memory at 0x1000:0x0000 (linear address
 ; 0x10000) and entered at 0x:1000:0x0200 with parameters eax - partition offset
 ; in 512 byte blocks and dl - BIOS ID of the boot drive.
@@ -639,7 +639,7 @@
 
 ; the path to the boot loader
 kPathComponents:
-pathComponent				"beos"
+pathComponent				"haiku"
 pathComponent				"system"
 pathComponent				"zbeos"
 							db	0
@@ -5,7 +5,7 @@
 ; position PARTITION_OFFSET_OFFSET (32 bit little endian; makebootable does
 ; that) or otherwise the code can't find the partition.
-; The partition must be a BFS formatted. The file "beos/system/zbeos"
+; The partition must be a BFS formatted. The file "haiku/system/zbeos"
 ; (the stage 2 boot loader) loaded into memory at 0x1000:0x0000 (linear address
 ; 0x10000) and entered at 0x:1000:0x0200 with parameters eax - partition offset